#!/usr/bin/env python
"""HWproject_ERAINT.py

Script to calculate EHF heatwaves from ERAINT based on the HWproject_AWAP.py script from Daniel Argueso @ CCRC, UNSW. Sydney (Australia)

Author: Annette Hirsch @ CLEX, UNSW. Sydney (Australia)
email: a.hirsch@unsw.edu.au
Created: Mon Apr  9 08:17:38 AEST 2018 

"""

import numpy as np
import datetime as dt
import netCDF4 as nc
from constants import const
from compute_EHFheatwaves import compute_EHF
import glob as glob
import sys
import HWvariables_info as hwv
import os
import pandas

def str2bool(v):
  return v.lower() in ("true")

def sel_files(filelist,pattern,syear,eyear):
    #print([fname.split(pattern)[-1][0:4] for fname in filelist])
    years=np.array([fname.split(pattern)[-1][0:4] for fname in filelist],np.int64)
    sel_files=[n for i,n in enumerate(filelist) if  ((years[i]<= eyear) & (years[i]>= syear))]
    return sel_files

def create_timebnds(time):
  time_bnds=np.zeros((len(time),2),dtype=np.float64)

  time_bnds[:-1,1]=time[:-1]+np.diff(time)/2
  time_bnds[:-1,0]=time[:-1]-np.diff(time)/2

  time_bnds[-1,0]=time[-1]-(time[-1]-time[-2])/2
  time_bnds[-1,1]=time[-1]+(time[-1]-time[-2])/2

  return time_bnds

#### USER MODIFICATION #####
start_time = dt.datetime.now()

domain='d01'

dir_in_dom = {'d01':'/g/data3/w97/azh561/cordex_australasia/ERAINT_on_CORDEX_AUS-44i/'}

pattern='CCRC_ERAINT_'
version = 'PA13'
EHFaccl = False
RCM = ''
GCM = 'AWAP'
syear = np.int('1981')
eyear = np.int('2009')

sy_base = np.int('1981') 
ey_base = np.int('2009')
thfile  = ''

dir_in = dir_in_dom[domain]
dir_out='/g/data3/w97/azh561/cordex_australasia/post_process/ERAINT_CORDEX_AUS-44i/Base_%s-%s/%s-%s/%s/' %(sy_base,ey_base,syear,eyear,domain)

month_starty = np.int('6')

seas    = 'yearly'

cal_out = 'standard'  
 
print('Which version of the EHF index? ', version)

refversion={'NF13':'Nairn and Fawcett 2013, CAWCR Technical Report 060',
            'PA13':'Perkins and Alexander 2013, Journal of Climate'}

thfile = '' #'/g/data3/w97/azh561/cordex_australasia/post_process/ERAINT_CORDEX_AUS-44i/Base_1981-2009/1981-2009/d01/CCRC_ERAINT_1981-2009_pct_PA13.nc'


if thfile=='':
  thfile=None
  
if ((sy_base<syear) or (ey_base>eyear)) and thfile==None:
  sys.exit('For a base period not included in the computation period a threshold file is required \n It wasn\'t provided. Please provide a threshold file')

if not os.path.exists(dir_out):
  os.makedirs(dir_out)

###############################################
###############################################
## LOADING FILES ##
###############################################
###############################################

ifiles=sorted(glob.glob('%s/tas/tas_????.nc' %(dir_in)))
selec_files=sel_files(ifiles,"tas_",syear-1,eyear)
print(selec_files)

files=nc.MFDataset(selec_files)
tave=files.variables['tas'][:]-const.tkelvin

times=files.variables['time'][:]

lat=files.variables['lat'][:]
lon=files.variables['lon'][:]
masklm=np.ones(tave.shape[1:],np.int)

dates=nc.num2date(times,units=files.variables['time'].units,calendar='standard')

years=np.asarray([dates[i].year for i in range(len(dates))])

tave=tave[(years>=syear-1) & (years<=eyear),:,:]

dates=dates[(years>=syear-1) & (years<=eyear)]
years=np.asarray([dates[i].year for i in range(len(dates))])
months_all=np.asarray([dates[i].month for i in range(len(dates))])
days_all=np.asarray([dates[i].day for i in range(len(dates))])

nyears=eyear-syear+1

files.close()


###############################################
###############################################
## CALLING COMPUTE HEATWAVE FUNCTION - it calculates the metrics
###############################################
###############################################


HWA,HWM,HWF,HWN,HWD,HWT,pctcalc,EHFindex,HWMt,HWAt,spell,HWL=compute_EHF(tave,dates,thres_file=thfile,bsyear=sy_base,beyear=ey_base,month_starty=month_starty,mask=masklm,EHFaccl=EHFaccl,method=version)


#################################################
########### WRITTING OUT NCFILES#################
#################################################

time_bnds_y=np.zeros((nyears,2),dtype=np.float64)
time_bnds_y[:,0]=nc.date2num([dt.datetime(syear+x,7,1,0) for x in range(0,nyears)],units='hours since 1949-12-01 00:00:00',calendar=cal_out)
time_bnds_y[:,1]=nc.date2num([dt.datetime(syear+x+1,7,1,0) for x in range(0,nyears)],units='hours since 1949-12-01 00:00:00',calendar=cal_out)

datesout_year=[dt.datetime(syear+x,6,1,0) for x in range(0,nyears)]
time_y=nc.date2num(datesout_year,units='hours since 1949-12-01 00:00:00',calendar=cal_out)

time_d=nc.date2num(dates,units='hours since 1949-12-01 00:00:00',calendar=cal_out)
time_bnds_d=create_timebnds(time_d)


print("Files will be written in: %s " %(dir_out))

var_arrays={'HWA_EHF':HWA,'HWM_EHF':HWM,'HWF_EHF':HWF,'HWN_EHF':HWN,'HWD_EHF':HWD,'HWT_EHF':HWT,'pct':pctcalc,'EHF':EHFindex,'HWAt_EHF':HWAt,'HWMt_EHF':HWMt,'spell':spell,'HWL_EHF':HWL}

varinfo = hwv.VariablesInfo()
outvar_names=varinfo.get_var_names()

for var in outvar_names:
    
    if var == 'pct':
        fout=nc.Dataset('%s/CCRC_ERAINT_%s-%s_%s_%s.nc'%(dir_out,syear,eyear,var,version),mode='w')
        fout.createDimension('y',lat.shape[0])
        fout.createDimension('x',lon.shape[0])

        outlat=fout.createVariable('lat','f8',('y'),fill_value=const.missingval)
        setattr(outlat,"standard_name","latitude")
        setattr(outlat,"long_name","Latitude")
        setattr(outlat,"units","degrees_north")
        setattr(outlat,"_CoordinateAxisType","Lat")

        outlon=fout.createVariable('lon','f8',('x'),fill_value=const.missingval)
        setattr(outlon,"standard_name","longitude")
        setattr(outlon,"long_name","Longitude")
        setattr(outlon,"units","degrees_east")
        setattr(outlon,"_CoordinateAxisType","Lon")
        
        if version=='PA13':
            
            fout.createDimension('doy',None)
            outdoy=fout.createVariable('doy','f8','doy',fill_value=const.missingval,zlib=True)
            setattr(outdoy,"standard_name","doy")
            setattr(outdoy,"long_name","Day of Year")
            setattr(outdoy,"calendar","standard")

            outvar=fout.createVariable('PRCTILE90','f4',('doy','y','x'),fill_value=const.missingval,zlib=True)
            for att in varinfo.get_atts(var):      
                setattr(outvar,att,varinfo.get_varatt(var,att))
        else:
            outvar=fout.createVariable('PRCTILE95','f8',('y','x'),fill_value=const.missingval,zlib=True)      
            for att in varinfo.get_atts(var):      
                setattr(outvar,att,varinfo.get_varatt(var,att))
        
        outlat[:]=lat[:]
        outlon[:]=lon[:]
        outvar[:]=var_arrays[var][:]
    
    else:
        
        if var in ['EHF','spell']:
            fout=nc.Dataset('%s/CCRC_ERAINT_%s-%s_%s_%s.nc'%(dir_out,syear,eyear,var,version),mode='w',format='NETCDF4_CLASSIC')
        else:
            fout=nc.Dataset('%s/CCRC_ERAINT_YEA_%s-%s_%s_%s.nc'%(dir_out,syear,eyear,var,version),mode='w',format='NETCDF4_CLASSIC')
            
        fout.createDimension('time',None)
        fout.createDimension('bnds',2)
        fout.createDimension('y',lat.shape[0])
        fout.createDimension('x',lon.shape[0])
        
        outtime=fout.createVariable('time','f8','time',fill_value=const.missingval,zlib=True)
        setattr(outtime,"standard_name","time")
        setattr(outtime,"long_name","Time")
        setattr(outtime,"bounds","time_bnds")
        setattr(outtime,'units','hours since 1949-12-01 00:00:00')
        setattr(outtime,"calendar","standard")

        outtimebnds=fout.createVariable('time_bnds','f8',('time','bnds'),fill_value=const.missingval,zlib=True)
        setattr(outtime,'units','hours since 1949-12-01 00:00:00')
        setattr(outtime,"calendar","standard")

        outlat=fout.createVariable('lat','f8',('y'),fill_value=const.missingval,zlib=True)
        setattr(outlat,"standard_name","latitude")
        setattr(outlat,"long_name","Latitude")
        setattr(outlat,"units","degrees_north")
        setattr(outlat,"_CoordinateAxisType","Lat")

        outlon=fout.createVariable('lon','f8',('x'),fill_value=const.missingval,zlib=True)
        setattr(outlon,"standard_name","longitude")
        setattr(outlon,"long_name","Longitude")
        setattr(outlon,"units","degrees_east")
        setattr(outlon,"_CoordinateAxisType","Lon")

        outvar=fout.createVariable(var,'f4',('time','y','x'),fill_value=const.missingval,zlib=True)
        for att in varinfo.get_atts(var):
            setattr(outvar,att,varinfo.get_varatt(var,att))
            
            if (var == 'HWT_EHF') & (att == 'description'):
                start_m = dt.datetime(1949,int(month_starty),1).strftime("%B") 
                setattr(outvar,att,varinfo.get_varatt(var,att).replace('%month%', start_m))
            
        if var in ['EHF','spell']:
            outtime[:]=time_d[:]
            outtimebnds[:]=time_bnds_d[:] 
        else: 
            outtime[:]=time_y[:]
            outtimebnds[:]=time_bnds_y[:]
            
        outlat[:]=lat[:]
        outlon[:]=lon[:]
        outvar[:]=var_arrays[var][:]
        
    # Setting global attributes
    
    setattr(fout,"Author", "Annette Hirsch @ CLEx, UNSW")
    setattr(fout,"contact", "a.hirsch@unsw.edu.au")
    setattr(fout,"creation_date",dt.datetime.today().strftime('%Y-%m-%d'))
    setattr(fout,"Method","Heat waves calculated using %s method (%s)" %(version,refversion[version]))
    setattr(fout,"base_period","File generated using the base period %s-%s" %(sy_base,ey_base))
    
    filesatt=nc.Dataset(selec_files[0],'r')
    for att in filesatt.ncattrs():
      if att != 'creation_date':
        setattr(fout, att, getattr(filesatt,att))
      else:
        setattr(fout,"creation_date",dt.datetime.today().strftime('%Y-%m-%d'))
    
    fout.close()
    
end_time = dt.datetime.now()
print("#################################")
print('Duration: {}'.format(end_time - start_time))
print("#################################")










