# hirsch-jgra-2019

This document contains all the information to reproduce the analysis for Hirsch et al. 2019 JGRA 'Amplification of Australian heatwaves via local land-atmosphere coupling'

Data Locations at the NCI. User account is necessary to use this but otherwise all data used can be downloaded from ESGF.

On raijin, processed data can be found in /g/data3/w97/azh561/cordex_australasia/

Raw CORDEX output: 
* UNSW WRF runs:  /g/data3/hh5/tmp/w28/gdv561/CORDEX/ERA-Int/ERA-Interim_post/postprocess/CORDEX/output/
* Murdoch WRF run:  /g/data3/w97/azh561/cordex_australasia/MU-WRF/AUS-44/day
* COSMO: /g/data3/w97/azh561/cordex_australasia/CCLM4-8/
* CCAM:   /g/data/ua8/CORDEX-tmp/CSIRO-EraInt-eval-tmp/AUS-44i/CSIRO/ECWMF-ERAINT/evaluation/r1i1p1/CSIRO-CCAM/v1/day/
    * I have a script in /g/data3/w97/azh561/cordex_australasia/CSIRO-CCAM/link.sh

Analysis

On raijin, most run on vdi but git repo on raijin /g/data3/w97/azh561/cordex_australasia/

Here I only describe the scripts used for the paper, there are several other scripts aswell for analysis that did not make it into the paper.

EHF Calculations

Working in /home/561/azh561/cordex_australasia/scripts/
* First load python environment
    * module use /g/data3/hh5/public/modules
    * module load conda/analysis3
* For WRF:
    * python Run_allmodels_EHF_HWproject.py 
    * calls HWproject_WRF.deck
    * there are some lines to comment/uncomment depending on the model and whether it has leap days or not
    * For the COSMO and Murdoch Uni WRF model data was only available on AUS-44 and needed to be interpolated to AUS-44i to be consistent with the other models. To do this run python interpolate_to_regular_grid_rev_28042018.py
* For AWAP:
    * regrid_AWAP.sh 
        * output written to  /g/data3/w97/azh561/cordex_australasia/AWAP_CORDEX_AUS-44i/
    * python HWproject_AWAP.py 
* For the MERRA2 reanalysis:
    * regrid_MERRA2.sh
        * Not very efficient but VDI software not up-to-date so running several small 1CPU jobs on raijin use qsub regrid_MERRA2.pbs
        * Can be use for SEB variables too
        * If using cdo remapcon must use cdo 1.9.2 - if using 1.8.2 then get weird stripes with MERRA2 data
        * Output written to /g/data3/w97/azh561/cordex_australasia/MERRA2_CORDEX_AUS-44i/
    * python HWproject_MERRA2.py 
* Best to process directly on raijin and can do so as an interactive job: interqsub -l ncpus=1 -l mem=32Gb -l walltime=4:00:00
* I have now create a new git repo for this scripts: git clone ssh://azh561@raijin.nci.org.au/home/561/azh561/cordex_australasia/.git
* To update the git repo where I am storing clones just use git pull
* Some models have issue with leap days and so if there are errors then comment out the lines that set Feb 29 to false.

Note that all output from the analysis will be written to: /g/data3/w97/azh561/cordex_australasia/post_process/

Splitting data and retrieving timeseries

* First need to further post-process the data on raijin: 
    * To get the variables, regrid and calculate the anomalies: 
        * regrid_<AWAP/ERAINT/GLEAM/MERRA2>.sh
        * splitup_DATA_<MERRA2/MODEL>.sh
        * splitup_EHF_<MERRA2/MODEL>.sh
        * For ERAINT, AWAP and GLEAM use the ONDJFM.sh script in the respective /g/data3/w97/azh561/cordex_australasia/post_process/<AWAP/ERAINT/GLEAM>_CORDEX_AUS-44i/
* Routines run on raijin to extract the time series that are saved to netcdf files in /g/data3/w97/azh561/cordex_australasia/:
    * get_gridded_timeseries.ipynb
        * Extracts the absolute and anomaly time series coincident with a HW event for various variables at each grid cell
        * Output is written to /g/data3/w97/azh561/cordex_australasia/gridded_HWall_????.nc
        * After running this script use /g/data3/w97/azh561/cordex_australasia/region.sh to select hyperslabs of the regions of interest and limit how much data is read in. Have done this for NA (Darwin region), EA, SEA, SA, NP (Nullarbor) and SWA regions that are included in the paper.
        * Time series starts from 60 days prior to HW start until the 13th day after the HW start

Calculate land-atmosphere coupling

* Details from http://cola.gmu.edu/dirmeyer/Coupling_metrics_V2-7_TwoLeg.pdf
* Requires that you have already got mrso, hfss and tas anomalies for each model and over Oct-March for each heatwave season year in 1981-2009 and split these by HW season
* Calculate the coupling using: /home/561/azh561/cordex_australasia/scripts/calc_two_legged_coupling.sh

Manuscript Figures

Scripts can be found in: /home/561/azh561/cordex_australasia/scripts/

1. Model Domain and sub-regions: using plot_topo.ipynb 
figurename OBS_vs_MOD_CORDEX-AustralAsia_TOPOGRAPHY.png
2. Bias in T90 percentile as contour maps: plot_EHF_OBS_vs_MOD_BIAS.ipynb
figurename: BIAS_OBS_vs_MOD_CORDEX-AustralAsia_1981-2009_pct_PA13.png
3. Summary plot of EHF skill: plot_EHF_Skill.ipynb 
figurename: SKILL_EHF_CORDEX-AustralAsia_ERAINT_1981-2009_PA13.png
4. Anomaly time series plot for subset of  regions and variables: plot_gridded_anomaly_timeseries_abbrev.ipynb 
figurename: gridcell_ts_OBS_vs_MOD_CORDEX-AustralAsia_1982-2009_EHF_anom_HWall_prgt1_subset.png
5. Probability of negative QE trend: plot_pr_negative_dXdt.ipynb 
figurename: pr_OBS_vs_MOD_CORDEX-AustralAsia_1982-2009_neg_dQEdt_14_days_preHW.png
6. KDE distributions QE trend: plot_distributions_kde.ipynb 
figurename: distributions_dQEdt_mrso_split_<Region>_ALL.png
7. KDE distributions of tas on first heatwave day split according to soil moisture quartile: plot_distributions_kde.ipynb 
figurename: distributions_tas_hwday_<X>_mrso_split_<Region>_ALL.png
8. KDE distributions of tas on Xth heatwave day split according to sign of hfls trend: plot_distributions_kde_dQEdt_split.ipynb 
figurename: distributions_tas_hwday_<X>_dQEdt_split_<Region>_ALL.png
9. Atmospheric-Leg QH and TAS: plot_two-legged_coupling.ipynb 
figurename: TWO-LEGGED_CS_norm_1981-2009_IA.png
10. KDE distributions of EHF diagnostics, all models, all grid cells: plot_EHF_ranked_by_two-legged_coupling.ipynb 
figurename: EHF_DSN_<EHF Diagnostic>_split_IA_Australia_ALL.png
11. KDE distributions of HWM and HWF, all models, by region: plot_EHF_ranked_by_two-legged_coupling.ipynb 
figurename: EHF_DSN_<EHF Diagnostic>_split_IA_Australia_ALL.png
12. Model Comparison of likelihood rations across EHF diagnostics: plot_LR_EHF_vs_two-legged_coupling.ipynb 
figurename: LR_SEPARATE_EHF_by_TWO-LEGGED_CS_1981-2009_<EHF Diagnostic>_EHF_vs_IA.png

Manuscript Supplementary Figures

Scripts can be found in: /home/561/azh561/cordex_australasia/scripts/

1. Contour maps of EHF diagnostic biases: plot_EHF_OBS_vs_MOD_BIAS.ipynb 
figurename: BIAS_OBS_vs_MOD_CORDEX-AustralAsia_1981-2009_<EHF diagnostic>_PA13.png
2. Must be run on raijin via PBS: Anomaly time series plot for all regions and variables: plot_gridded_anomaly_timeseries.ipynb 
figurename: gridcell_ts_OBS_vs_MOD_CORDEX-AustralAsia_1982-2009_EHF_anom_HWall_prgt1_6regions.png
3. KDE distributions of tas on first heatwave day individual models for NA: plot_distributions_kde.ipynb 
figurename: distributions_tas_hwday_0_mrso_split_Darwin.png
4. KDE distributions of tas on second and fourth heatwave days: plot_distributions_kde.ipynb 
figurename: distributions_tas_hwday_<2/4>_mrso_split_<Region>_ALL.png
5. Terrestrial-Leg MRSO and QH: plot_two-legged_coupling.ipynb 
figurename: TWO-LEGGED_CS_norm_1981-2009_IL.png
6. Full coupling MRSO and TAS: plot_two-legged_coupling.ipynb 
figurename: TWO-LEGGED_CS_norm_1981-2009_ILA.png
7. Relationship between EHF and two-legged CS: plot_EHF_vs_two-legged_coupling.ipynb 
figurename: EHF_vs_TWO-LEGGED_CS_1981-2009_<EHF Diagnostic>_EHF_vs_IA_ALL.png
8. Contour maps of the two-legged coupling components: plot_two-legged_coupling_components.ipynb 
figurename TWO-LEGGED_CS_SD_COMPONENT_1981-2009_<VAR>.png
