
#!/usr/bin/env python

""" Run_allmodels_EHF_HWproject.py

Author: Daniel Argueso @ CCRC, UNSW. Sydney (Australia)
email: d.argueso@ unsw.edu.au
Created: Fri May 30 14:49:46 EST 2014

Modified: Mon Mar 05 10:06:53 AEDT 2018 - Annette L Hirsch @ CLEx a.hirsch@unsw.edu.au for application to the CORDEX-AustralAsia data

"""
import subprocess as subprocess
import os.path
import shutil
import numpy as np
import pdb

# User defined inputs

# For data on raw rotated pole grid
#MAIN_DIRECTORY='/g/data1/ua8/tmp/CCRC_WRF3-6-0-5_SEB/ERA-Interim_post/postprocess/CORDEX/output/'
#Domain_names=['AUS-44']# AUS-44 (raw rotated pole grid) or AUS-44i (interpolated lat/lon CORDEX grid for multi-model comp)
#Domain_grid='Rotated Pole'
#version='r1p1i1'

# For data on interpolated lat/lon grid
# For UNSW-WRF360
#MAIN_DIRECTORY='/g/data3/hh5/tmp/w28/gdv561/CORDEX/ERA-Int/ERA-Interim_post/postprocess/CORDEX/output/'
#Institute='UNSW'

# For CCLM
#MAIN_DIRECTORY='/g/data3/w97/azh561/cordex_australasia/CCLM4-8/'
#RCM_names=['CLMcom-CCLM4-8-17-CLM3-5']

# For CCAM
MAIN_DIRECTORY='/g/data3/w97/azh561/cordex_australasia/CSIRO-CCAM/'
RCM_names=['CSIRO-CCAM']

BC_names=['ECMWF-ERAINT']
Domain_names=['AUS-44i']# AUS-44 (raw rotated pole grid) or AUS-44i (interpolated lat/lon CORDEX grid for multi-model comp)
Domain_grid='Interpolated Lat/Lon CORDEX'
vnumber='v1'
version='r1i1p1'
vtype='evaluation'
interval='day'
Period_base='1981-2010' #Last year isn't included
HWtype="PA13" #NF13 or PA13
data_type = 'pp' # 'pp':'Raw', 'bc':'Bias_corrected'
outpath="/g/data3/w97/azh561/cordex_australasia/post_process/"
indeck="HWproject_WRF.deck"
maskfile='' # Path and name

# Define the experiment option
# 'simple' - calculates the difference between a future period and the present day with no smoothing
# 'nday_win' - calculates the same difference as 'simple' but applies a smoothing window of ndays which the user must specify
# 'fixed-delta' - currently does nothing 
exps = {"a": ["1950-2010", "", ""],
       "b": ["2060-2080", "", ""],
       "c": ["2060-2080", "simple", ""],
       "d": ["2060-2080", "nday_win", "90"],
       "e": ["1990-2010", "fixed_delta", ""],
       "f": ["1980-2010", "", ""],
       "g": ["1981-2010", "", ""]}

exps_let = ["g"]

month_starty = 6 # When do we consider the start of the year
syear_pres = '1981'
eyear_pres = '2010'

# Program start - do not edit below this line

if HWtype not in ['PA13','NF13']:
  sys.error('ERROR: The chosen EHF HWtype is not supported, please choose between NF13, PA13')
  
for expi in exps_let:
    
  pname   = exps[expi][0]
  method  = exps[expi][1]
  nwin_days=exps[expi][2]
    
  for gind,gname in enumerate(BC_names):
    for rind,rname in enumerate(RCM_names): 
      for dind,dname in enumerate(Domain_names):
        
        print("Calculating EHF_Index for: ",gname,rname,pname,dname)

        #Define input location
        if dname=='AUS-44' and rname not in [ 'CCAM','CLMcom-CCLM4-8-17-CLM3-5']:
            # For AUS-44
            path_in=str.join("/",[MAIN_DIRECTORY,dname,Institute,gname,vtype,version,rname,vnumber,interval])
            path_in_pres=str.join("/",[MAIN_DIRECTORY,dname,Institute,gname,vtype,version,rname,vnumber,interval])

        # For AUS-44i
        if rname=='CSIRO-CCAM':            
            path_in=str.join("/",[MAIN_DIRECTORY,interval])
            path_in_pres=str.join("/",[MAIN_DIRECTORY,interval])
        if rname=='CLMcom-CCLM4-8-17-CLM3-5':            
            path_in=str.join("/",[MAIN_DIRECTORY,dname,rname,interval])
            path_in_pres=str.join("/",[MAIN_DIRECTORY,dname,rname,interval])
        #if dname=='AUS-44i' and rname not in [ 'CSIRO-CCAM','CLMcom-CCLM4-8-17-CLM3-5']:
        #    path_in=str.join("/",[MAIN_DIRECTORY,dname,Institute,gname,vtype,version,rname,vnumber,'d01',interval])
        #    path_in_pres=str.join("/",[MAIN_DIRECTORY,dname,Institute,gname,vtype,version,rname,vnumber,'d01',interval])
        print(path_in)

        pattern=str.join("_",[dname,gname,vtype,version,rname,vnumber,interval])
        
        #Define output location
        if data_type not in ['bc','pp']:
          print("ERROR: The data type chosen is not supported or defined. Choose either bc or pp")
    
        # Define what type of data you are using
        datatype_dir={'pp':'Raw', 'bc':'Bias_corrected'}
        
        fullpathout=str.join("/",[outpath,datatype_dir[data_type],"%s%s" %(method,nwin_days),gname,rname,"%s-%s" %(Period_base[0:4],int(Period_base[5:])-1),dname])
        print(fullpathout)
        if not os.path.exists(fullpathout):
          os.makedirs(fullpathout)        
        
        #Reading threshold file is necessary
        if (pname=='1981-2010') & (method==""):
          thfile = ''
        else:
          thfile = str.join("/",[outpath,datatype_dir[data_type],gname,rname,"%s-%s" %(Period_base[0:4],int(Period_base[5:])-1),dname,'CORDEX-AustralAsia_%s-%s_pct_%s.nc' %(Period_base[0:4],int(Period_base[5:])-1,HWtype)])

        # Define the EHF file - if this exists then call the extractSEB_MOD.deck instead
#        ehffile = str.join("/",[outpath,datatype_dir[data_type],gname,rname,"%s-%s" %(Period_base[0:4],int(Period_base[5:])-1),dname,'CORDEX-AustralAsia_%s-%s_EHF_%s.nc' %(Period_base[0:4],int(Period_base[5:])-1,HWtype)])
#        if os.path.isfile(ehffile):
        #if ehffile.exists():
#            indeck="extractSEB_MOD.deck"
#            fout = open ("extractSEB_MOD.py","w")
#            inputfile = ehffile
#            print("EHF has been calculated...extract SEB components")
#        else:
#            fout = open ("HWproject_WRF.py","w")
#            inputfile = thfile

        fout = open ("HWproject_WRF.py","w")
        inputfile = thfile
        fin = open (indeck,"r")
           
        #Creating dictionary to populate namelist
        namelist_dic={'%dir_in%':   path_in,
                      '%dir_in_pres%' : path_in_pres,
                      '%pattern%':  pattern,
                      '%dir_out%':  fullpathout,
                      '%RCM%':      rname,
                      '%BC%':      gname,
                      '%syear%':    pname[0:4],
                      '%eyear%':    pname[5:],
                      '%syear_pres%': syear_pres,
                      '%eyear_pres%': str(int(eyear_pres)-1),
                      '%seas%':     'yearly',
                      '%sy_base%':  Period_base[0:4],
                      '%ey_base%':  str(int(Period_base[5:])-1),
                      '%thfile%':   inputfile,
                      '%HWtype%':    HWtype,
                      '%data_type%': data_type,
                      '%method%' :    method,
                      '%nwin_days%': nwin_days,
                      '%fixed_delta%': str(0.0),
                      '%month_starty%': str(month_starty),
                      '%filemask%': maskfile,
                      '%datagrid%': Domain_grid,
                      '%domain%': dname,
                      }
                
        for line in fin.readlines():
          for linerep in namelist_dic.keys():
            line=line.replace(linerep,namelist_dic[linerep])
          fout.write(line)
        fin.close()
        fout.close()

#        if os.path.isfile(ehffile):
#            subprocess.call(['python', './extractSEB_MOD.py'])
#        else:
#            subprocess.call(['python', './HWproject_WRF.py'])
        subprocess.call(['python', './HWproject_WRF.py'])
	
