#!/bin/bash
#PBS -P w97
#PBS -q express
#PBS -l walltime=1:00:00,mem=2GB
#PBS -l wd

module purge
module load pbs dot
module load netcdf/4.4.1.1
module load nco
module load cdo/1.8.2

# This script calculates Paul Dirmeyer's two-legged coupling metrics  http://cola.gmu.edu/dirmeyer/Coupling_metrics_V2-7_TwoLeg.pdf 
#Author: Annette Hirsch @ CCRC, UNSW. Sydney (Australia)
#email: a.hirsch@unsw.edu.au
#Created: Thu Nov 22 11:15:21 AEDT 2018 

## Input arguments

WORKDIR='/short/w97/azh561/tmp/'
MAINOUTDIR="/g/data3/w97/azh561/cordex_australasia/post_process/Raw/ECMWF-ERAINT/"
MODELS=( "CLMcom-CCLM4-8-17-CLM3-5" "CSIRO-CCAM" "MU-WRF330" "UNSW-WRF360J" "UNSW-WRF360K" "UNSW-WRF360L" )
PERIOD="1981-2009"
RES="AUS-44i"
PREFIX="CORDEX-AustralAsia_1981-2009"
SYEAR=1981
EYEAR=2009

# Loop through models and years
for mm in ${MODELS[@]}; do

  DATADIR=${MAINOUTDIR}${mm}/${PERIOD}/${RES}

  if [ ${mm} == "MU-WRF330" ]; then
    YEAR=$((${SYEAR}+1))
  else
    YEAR=${SYEAR}
  fi
  while [ ${YEAR} -lt $((${EYEAR}+1)) ]; do

    # Calculate the standard deviation over all timesteps for QH and T2
    cdo timstd ${DATADIR}/${PREFIX}_hfss_${YEAR}_ONDJFM.nc ${WORKDIR}/sd_hfss.nc
    cdo timstd ${DATADIR}/${PREFIX}_tas_${YEAR}_ONDJFM.nc ${WORKDIR}/sd_tas.nc
   
    # Calculate the correlation between variables
    # Soil moisture and QH
    cdo timcor ${DATADIR}/${PREFIX}_mrso_${YEAR}_ONDJFM.nc ${DATADIR}/${PREFIX}_hfss_${YEAR}_ONDJFM.nc ${WORKDIR}/cor_mrso_hfss.nc
    # QH and T2
    cdo timcor ${DATADIR}/${PREFIX}_hfss_${YEAR}_ONDJFM.nc ${DATADIR}/${PREFIX}_tas_${YEAR}_ONDJFM.nc ${WORKDIR}/cor_hfss_tas.nc
    # Soil moisture and T2
    cdo timcor ${DATADIR}/${PREFIX}_mrso_${YEAR}_ONDJFM.nc ${DATADIR}/${PREFIX}_tas_${YEAR}_ONDJFM.nc ${WORKDIR}/cor_mrso_tas.nc

    # Calculate the terrestrial-leg coupling
    cdo mul ${WORKDIR}/sd_hfss.nc ${WORKDIR}/cor_mrso_hfss.nc ${DATADIR}/${PREFIX}_IL_${YEAR}_ONDJFM.nc    
    ncrename -v hfss,IL ${DATADIR}/${PREFIX}_IL_${YEAR}_ONDJFM.nc
    ncatted -a units,IL,o,c,"" ${DATADIR}/${PREFIX}_IL_${YEAR}_ONDJFM.nc
    ncatted -a long_name,IL,o,c,"Thermal Terrestrial Coupling" ${DATADIR}/${PREFIX}_IL_${YEAR}_ONDJFM.nc
    ncatted -a standard_name,IL,o,c,"Thermal Terrestrial Coupling" ${DATADIR}/${PREFIX}_IL_${YEAR}_ONDJFM.nc

    # Calculate the atmospheric-leg coupling
    cdo mul ${WORKDIR}/sd_tas.nc ${WORKDIR}/cor_hfss_tas.nc ${DATADIR}/${PREFIX}_IA_${YEAR}_ONDJFM.nc
    ncrename -v tas,IA ${DATADIR}/${PREFIX}_IA_${YEAR}_ONDJFM.nc
    ncatted -a units,IA,o,c,"" ${DATADIR}/${PREFIX}_IA_${YEAR}_ONDJFM.nc
    ncatted -a long_name,IA,o,c,"Thermal Atmospheric Coupling" ${DATADIR}/${PREFIX}_IA_${YEAR}_ONDJFM.nc
    ncatted -a standard_name,IA,o,c,"Thermal Atmospheric Coupling" ${DATADIR}/${PREFIX}_IA_${YEAR}_ONDJFM.nc

    # Calculate the full land-atmosphere coupling
    cdo mul ${WORKDIR}/sd_tas.nc ${WORKDIR}/cor_mrso_tas.nc ${DATADIR}/${PREFIX}_ILA_${YEAR}_ONDJFM.nc
    ncrename -v tas,ILA ${DATADIR}/${PREFIX}_ILA_${YEAR}_ONDJFM.nc
    ncatted -a units,ILA,o,c,"" ${DATADIR}/${PREFIX}_ILA_${YEAR}_ONDJFM.nc
    ncatted -a long_name,ILA,o,c,"Thermal Land-Atmospheric Coupling" ${DATADIR}/${PREFIX}_ILA_${YEAR}_ONDJFM.nc
    ncatted -a standard_name,ILA,o,c,"Thermal Land-Atmospheric Coupling" ${DATADIR}/${PREFIX}_ILA_${YEAR}_ONDJFM.nc

    # Clean-up
    rm ${WORKDIR}/sd_hfss.nc
    rm ${WORKDIR}/sd_tas.nc
    rm ${WORKDIR}/cor_mrso_hfss.nc
    rm ${WORKDIR}/cor_hfss_tas.nc
    rm ${WORKDIR}/cor_mrso_tas.nc

    # Advance next year
    YEAR=$((${YEAR}+1))

  done # while [ ${YEAR} -lt $((${FIYEAR}+1)) ]; do

done # for mm in ${MODELS[@]}; do


