#!/bin/bash
#PBS -P w97
#PBS -q express
#PBS -l walltime=2:00:00,mem=55GB
#PBS -l wd
#PBS -l ncpus=1

module purge
module load pbs dot
module load nco
module load cdo

# This script regrids the AWAP data onto the interpolated lat/lon CRODEX domain
# to enable direct comparison between AWAP and WRF output
#
# Created: Mon Mar 12 08:22:15 AEDT 2018 by Annette L Hirsch @ CLEX, UNSW a.hirsch@unsw.edu.au

# Program Start

# USER INPUT ARGUMENTS

RES="AUS-44i"
INPUT_DIR="/g/data3/w97/azh561/cordex_australasia/AWAP/"
OUTPUT_DIR="/g/data3/w97/azh561/cordex_australasia/AWAP_on_CORDEX_${RES}/"

#VARIABLES=( "tmax" "tmin" )
VARIABLES=( "pre" )

STYEAR=1979
FIYEAR=2011

cat > targetgrid << EOF
gridtype=lonlat
xsize=238
ysize=133
yfirst=-53.25
yinc=0.5
xfirst=88.75
xinc=0.5
EOF


for vv in ${VARIABLES[@]}; do

  mkdir -p ${OUTPUT_DIR}/${vv}

  YEAR=${STYEAR}

  while [ ${YEAR} -lt $((${FIYEAR}+1)) ]; do

    IFILE="${INPUT_DIR}/${vv}/${vv}.${YEAR}.nc"
    OFILE="${OUTPUT_DIR}/${vv}/${vv}.${YEAR}.nc"

    dateyear=`date -d ${YEAR}-01-01 +%s`
    refdate=`date -d 1950-01-01 +%s`
    OFFSET=$(((${dateyear} - ${refdate})/86400))

    ncap2 -O -s "time=time-$((${YEAR}*1000))+${OFFSET}" ${IFILE} tmp.nc
    ncatted -O -a calendar,time,c,c,"proleptic_gregorian" tmp.nc
    ncatted -a long_name,time,o,c,"time"  tmp.nc
    ncatted -a units,time,o,c,"days since 1950-01-01 00:00:00"  tmp.nc  
    cdo remapbil,targetgrid tmp.nc ${OFILE}
    rm tmp.nc

    YEAR=$((${YEAR}+1))

  done # while [ ${YEAR} -lt $((${FIYEAR}+1)) ]; do

done # for vv in ${VARIABLES[@]}; do

