#!/bin/bash
#PBS -P w97
#PBS -q express
#PBS -l walltime=24:00:00,mem=12GB
#PBS -l wd

module purge
module load pbs dot
module load netcdf/4.4.1.1
module load nco
module load cdo/1.8.2

# This program regrids the ERAINT to CORDEX AUS-44i and converts to QE
#
# Created: Wed May 23 09:25:21 AEST 2018 by Annette L Hirsch @ CLEX, UNSW a.hirsch@unsw.edu.au

# Program Start

# USER INPUT ARGUMENTS

RES="AUS-44i"
INPUT_DIR="/g/data1/ub4/erai/netcdf/"
REGRID_DIR="/g/data3/w97/azh561/cordex_australasia/ERAINT_on_CORDEX_${RES}/"
TMP_DIR="/short/w97/azh561/tmp/"
SYEAR=1980
EYEAR=2009
VARIABLES=( "hfss" "hfls" "rsds" "tas" "tp" "strd" "ts" )

cat > targetgrid << EOF
gridtype=lonlat
xsize=238
ysize=133
yfirst=-53.25
yinc=0.5
xfirst=88.75
xinc=0.5
EOF

echo 'Start time: '`date`

for vv in ${VARIABLES[@]}; do

  mkdir -p ${REGRID_DIR}/${vv}

  YEAR=${SYEAR}

  if [[ ${vv} =~ ^(hfss|hfls|rsds|tas|tp|strd)$ ]]; then 
    INDIR="${INPUT_DIR}/3hr/atmos/oper_fc_sfc/v01/"
    FPREFIX="_3hrs_ERAI_historical_fc-sfc_"
  elif [[ ${vv} =~ ^(ts)$ ]]; then 
    INDIR="${INPUT_DIR}/6hr/land/oper_an_sfc/v01/"
    FPREFIX="_6hrs_ERAI_historical_land_"
  fi

  # Loop through the years
  while [ ${YEAR} -lt $((${EYEAR}+1)) ]; do

      # Calculate daily averages
      cd ${INDIR}/${vv}/
      FILES=`ls -1 ${vv}${FPREFIX}${YEAR}*.nc`
      for ff in ${FILES[@]}; do
        cdo remapbil,${TMP_DIR}/targetgrid ${ff} ${TMP_DIR}/${ff}
      done

      ncrcat `ls -1 ${TMP_DIR}/${vv}_*` ${TMP_DIR}/${vv}_${YEAR}.nc

      if [[ ${vv} =~ ^(hfss|hfls|rsds|strd)$ ]]; then       
        # If the variable is a radiative flux then the values in the raw netcdf files are 
        # accumulative fluxes rather than instantaneous fluxes
        ncks -d time,3,,8 ${TMP_DIR}/${vv}_${YEAR}.nc ${TMP_DIR}/${vv}_${YEAR}_18h.nc
        ncap2 -s "${vv}[time,lat,lon]=${vv}[time,lat,lon]/86400." ${TMP_DIR}/${vv}_${YEAR}_18h.nc ${REGRID_DIR}/${vv}/${vv}_${YEAR}.nc
      else
        cdo -daymean ${TMP_DIR}/${vv}_${YEAR}.nc ${REGRID_DIR}/${vv}/${vv}_${YEAR}.nc
      fi

      rm ${TMP_DIR}/${vv}_*

      YEAR=$((${YEAR}+1))
  done # while [ ${YEAR} -lt $((${EYEAR}+1)) ]; do

  # Calculate the daily climatologies
  ncrcat `ls -1 ${REGRID_DIR}/${vv}/${vv}_198[1-9].nc` `ls -1 ${REGRID_DIR}/${vv}/${vv}_199[0-9].nc` `ls -1 ${REGRID_DIR}/${vv}/${vv}_200[0-9].nc` "${REGRID_DIR}/${vv}/${vv}_${SYEAR}_${EYEAR}.nc"

  cdo ydaymean "${REGRID_DIR}/${vv}/${vv}_${SYEAR}_${EYEAR}.nc" "${REGRID_DIR}/${vv}/${vv}_${SYEAR}_${EYEAR}_ydaymean.nc"

  YEAR=${SYEAR}
  while [ ${YEAR} -lt $((${EYEAR}+1)) ]; do

    # Calculate the anomalies
    cdo ydaysub "${REGRID_DIR}/${vv}/${vv}_${YEAR}.nc" "${REGRID_DIR}/${vv}/${vv}_${SYEAR}_${EYEAR}_ydaymean.nc" "${REGRID_DIR}/${vv}/${vv}_${YEAR}_anom.nc"

    cdo splityear "${REGRID_DIR}/${vv}/${vv}_${YEAR}.nc" "${REGRID_DIR}/${vv}/${vv}_${YEAR}_"
    rm "${REGRID_DIR}/${vv}/${vv}_${YEAR}_$((${YEAR}+1)).nc"
    mv "${REGRID_DIR}/${vv}/${vv}_${YEAR}_${YEAR}.nc" "${REGRID_DIR}/${vv}/${vv}_${YEAR}.nc"
    cdo splityear "${REGRID_DIR}/${vv}/${vv}_${YEAR}_anom.nc" "${REGRID_DIR}/${vv}/${vv}_${YEAR}_anom_"
    rm "${REGRID_DIR}/${vv}/${vv}_${YEAR}_anom_$((${YEAR}+1)).nc"
    mv "${REGRID_DIR}/${vv}/${vv}_${YEAR}_anom_${YEAR}.nc" "${REGRID_DIR}/${vv}/${vv}_${YEAR}_anom.nc"

    YEAR=$((${YEAR}+1))

  done # while [ ${YEAR} -lt $((${EYEAR}+1)) ]; do

  ncrcat `ls -1 ${REGRID_DIR}/${vv}/${vv}_*_anom.nc` ${REGRID_DIR}/${vv}/${vv}_${SYEAR}_${EYEAR}_anom.nc

  FILES=`ls -1 ${REGRID_DIR}/${vv}/*.nc`
  for ff in ${FILES[@]}; do
      # To convert to netcdf4-classic to work for climpact2 and EHF function
      mv ${ff} tmp.nc
      ncks -7 tmp.nc ${ff}
      rm tmp.nc
  done

done # for vv in ${VARIABLES[@]}; do

