#!/bin/bash
#PBS -P w97
#PBS -q normal
#PBS -l walltime=48:00:00,mem=12GB
#PBS -l wd

module purge
module load pbs dot
module load netcdf/4.4.1.1
module load nco
module load cdo/1.8.2

# This program regrids the GLEAM ET to CORDEX AUS-44i and converts to QE
#
# Created: Wed May 23 09:25:21 AEST 2018 by Annette L Hirsch @ CLEX, UNSW a.hirsch@unsw.edu.au

# Program Start

# USER INPUT ARGUMENTS

RES="AUS-44i"
INPUT_DIR="/g/data/wd9/BenchMarking/GLEAM_v3-2/v3-2a/"
REGRID_DIR="/g/data3/w97/azh561/cordex_australasia/GLEAM_on_CORDEX_${RES}/"
RUN_DIR="/short/w97/azh561/"
TMP_DIR="${RUN_DIR}/tmp/"
mkdir -p ${TMP_DIR}
Lv=$((25*10**5))
ENDFIX="_GLEAM_v3.2a.nc"
SYEAR=1980
EYEAR=2009

cat > targetgrid << EOF
gridtype=lonlat
xsize=238
ysize=133
yfirst=-53.25
yinc=0.5
xfirst=88.75
xinc=0.5
EOF

  mkdir -p ${REGRID_DIR}

  # Loop through the years
  YEAR=${SYEAR}
  while [ ${YEAR} -lt $((${EYEAR}+1)) ]; do

    cdo remapbil,${RUN_DIR}/targetgrid "${INPUT_DIR}${YEAR}/E_${YEAR}${ENDFIX}" "${REGRID_DIR}/E_${YEAR}.nc"
    # Convert to W/m2
    ncap2 -s "hfls[time,lon,lat]=(E[time,lon,lat]*2500000.)/86400." "${REGRID_DIR}/E_${YEAR}.nc" "${REGRID_DIR}/hfls_${YEAR}.nc"
    ncatted -a long_name,hfls,o,c,"Daily mean latent heat flux" "${REGRID_DIR}/hfls_${YEAR}.nc"
    ncatted -a units,hfls,o,c,"W m^-2" "${REGRID_DIR}/hfls_${YEAR}.nc"

    YEAR=$((${YEAR}+1))

  done # while [ ${YEAR} -lt $((${EYEAR}+1)) ]; do

  SYEAR=1980
  # Calculate the anomalies of 1981-2009

  ncrcat `ls -1 ${REGRID_DIR}/hfls_198[1-9].nc` `ls -1 ${REGRID_DIR}/hfls_199[0-9].nc` `ls -1 ${REGRID_DIR}/hfls_200[0-9].nc` "${REGRID_DIR}/hfls_${SYEAR}_${EYEAR}.nc"

  cdo ydaymean "${REGRID_DIR}/hfls_${SYEAR}_${EYEAR}.nc" "${REGRID_DIR}/hfls_${SYEAR}_${EYEAR}_ydaymean.nc"

  YEAR=${SYEAR}
  while [ ${YEAR} -lt $((${EYEAR}+1)) ]; do

    # Calculate the anomalies
    cdo ydaysub "${REGRID_DIR}/hfls_${YEAR}.nc" "${REGRID_DIR}/hfls_${SYEAR}_${EYEAR}_ydaymean.nc" "${REGRID_DIR}/hfls_${YEAR}_anom.nc"

    YEAR=$((${YEAR}+1))

  done # while [ ${YEAR} -lt $((${EYEAR}+1)) ]; do

  ncrcat `ls -1 ${REGRID_DIR}/hfls_*_anom.nc` ${REGRID_DIR}/hfls_${SYEAR}_${EYEAR}_anom.nc


