#!/bin/bash
#PBS -P w97
#PBS -q express
#PBS -l walltime=2:00:00,mem=12GB
#PBS -l wd

module purge
module load pbs dot
module load netcdf/4.4.1.1
module load nco
module load cdo/1.8.2

# This script splits up the EHF 30 year daily data files to limit it just to the summer months

#Author: Annette Hirsch @ CCRC, UNSW. Sydney (Australia)
#email: a.hirsch@unsw.edu.au
#Created: Thu Apr 19 09:02:25 AEST 2018 

## Input arguments

WORKDIR='/short/w97/azh561/tmp/'

MERRAINDIR="/g/data3/w97/azh561/cordex_australasia/MERRA2_on_CORDEX_AUS-44i/"
MERRAOUTDIR="/g/data3/w97/azh561/cordex_australasia/post_process/MERRA2_CORDEX_AUS-44i/Base_1981-2009/1981-2009/d01/"
MERRAPFIX="CCRC_MERRA2_1981-2009_"
MERRAVAR=( "ALBEDO" "CLDTOT" "EFLUX" "EMIS" "EVAP" "EFLUX" "HFLUX" "LWGAB" "LWGEM" "LWGNT" "SWGDN" "SWGNT" "TS" "tmin" "tmax" "T2M" )

ENDFIX=".nc"

# Start with MERRA data

SYEAR=1980
EYEAR=2009

for vv in ${MERRAVAR[@]}; do

  # First fix MERRA time variable
  INFILES=`ls -1 ${MERRAINDIR}${vv}/${vv}_*.nc`
  for i in ${INFILES[@]}; do
    YEAR=${i: -7:4}
    dateyear=`date -d ${YEAR}-01-01 +%s`
    refdate=`date -d 1950-01-01 +%s`
    STDATE=$((1+((${dateyear} - ${refdate})/86400)))
    echo ${STDATE}
    ncap2 -O -s 'time=array('${STDATE}',1,$time)' ${i} ${WORKDIR}/${vv}_${YEAR}.nc
    cdo splitmon ${WORKDIR}/${vv}_${YEAR}.nc "${WORKDIR}/${vv}_${YEAR}_"
  done

  ncrcat `ls -1 ${WORKDIR}/${vv}_198[1-9].nc` `ls -1 ${WORKDIR}/${vv}_199[0-9].nc` `ls -1 ${WORKDIR}/${vv}_200[0-9].nc` `ls -1 ${WORKDIR}/${vv}_2009.nc` ${WORKDIR}/${vv}_${SYEAR}_${EYEAR}.nc
  cdo ydaymean ${WORKDIR}/${vv}_${SYEAR}_${EYEAR}.nc ${WORKDIR}/${vv}_${SYEAR}_${EYEAR}_ydaymean.nc

  YEAR=${SYEAR}
  while [ ${YEAR} -lt $((${EYEAR}+1)) ]; do

    # Calculate the anomalies
    cdo ydaysub ${WORKDIR}/${vv}_${YEAR}.nc ${WORKDIR}/${vv}_${SYEAR}_${EYEAR}_ydaymean.nc ${WORKDIR}/anom_${vv}_${YEAR}.nc  
    cdo splitmon ${WORKDIR}/anom_${vv}_${YEAR}.nc ${WORKDIR}/anom_${vv}_${YEAR}_
    YEAR=$((${YEAR}+1))
  
  done # while [ ${YEAR} -lt $((${FIYEAR}+1)) ]; do

  YEAR=${SYEAR}
  while [ ${YEAR} -lt ${EYEAR} ]; do

    ncrcat `ls -1 ${WORKDIR}/${vv}_${YEAR}_1[0-2].nc` ${WORKDIR}/${vv}_${YEAR}_OND.nc
    ncrcat `ls -1 ${WORKDIR}/anom_${vv}_${YEAR}_1[0-2].nc` ${WORKDIR}/anom_${vv}_${YEAR}_OND.nc
    ncrcat `ls -1 ${WORKDIR}/${vv}_${YEAR}_09.nc` `ls -1 ${WORKDIR}/${vv}_${YEAR}_1[0-2].nc` ${WORKDIR}/${vv}_${YEAR}_SOND.nc
    ncrcat `ls -1 ${WORKDIR}/anom_${vv}_${YEAR}_09.nc` `ls -1 ${WORKDIR}/anom_${vv}_${YEAR}_1[0-2].nc` ${WORKDIR}/anom_${vv}_${YEAR}_SOND.nc
    YEAR=$((${YEAR}+1))
    ncrcat `ls -1 ${WORKDIR}/${vv}_${YEAR}_0[1-3].nc` ${WORKDIR}/${vv}_${YEAR}_JFM.nc
    ncrcat `ls -1 ${WORKDIR}/anom_${vv}_${YEAR}_0[1-3].nc` ${WORKDIR}/anom_${vv}_${YEAR}_JFM.nc
    ncrcat `ls -1 ${WORKDIR}/${vv}_${YEAR}_0[1-8].nc` ${WORKDIR}/${vv}_${YEAR}_JFMAMJJA.nc
    ncrcat `ls -1 ${WORKDIR}/anom_${vv}_${YEAR}_0[1-8].nc` ${WORKDIR}/anom_${vv}_${YEAR}_JFMAMJJA.nc
    ncrcat ${WORKDIR}/${vv}_$((${YEAR}-1))_OND.nc ${WORKDIR}/${vv}_${YEAR}_JFM.nc ${WORKDIR}/${vv}_${YEAR}_ONDJFM.nc
    ncrcat ${WORKDIR}/anom_${vv}_$((${YEAR}-1))_OND.nc ${WORKDIR}/anom_${vv}_${YEAR}_JFM.nc ${WORKDIR}/anom_${vv}_${YEAR}_ONDJFM.nc
    ncrcat ${WORKDIR}/${vv}_$((${YEAR}-1))_SOND.nc ${WORKDIR}/${vv}_${YEAR}_JFMAMJJA.nc ${WORKDIR}/${vv}_SEP_$((${YEAR}-1))_AUG_${YEAR}.nc
    ncrcat ${WORKDIR}/anom_${vv}_$((${YEAR}-1))_SOND.nc ${WORKDIR}/anom_${vv}_${YEAR}_JFMAMJJA.nc ${WORKDIR}/anom_${vv}_SEP_$((${YEAR}-1))_AUG_${YEAR}.nc
    mv ${WORKDIR}/${vv}_${YEAR}_ONDJFM.nc ${MERRAOUTDIR}${MERRAPFIX}${vv}_${YEAR}_ONDJFM${ENDFIX}
    mv ${WORKDIR}/anom_${vv}_${YEAR}_ONDJFM.nc ${MERRAOUTDIR}${MERRAPFIX}${vv}_${YEAR}_ONDJFM_anom${ENDFIX}
    mv ${WORKDIR}/${vv}_SEP_$((${YEAR}-1))_AUG_${YEAR}.nc ${MERRAOUTDIR}${MERRAPFIX}${vv}_SEP_$((${YEAR}-1))_AUG_${YEAR}${ENDFIX}
    mv ${WORKDIR}/anom_${vv}_SEP_$((${YEAR}-1))_AUG_${YEAR}.nc ${MERRAOUTDIR}${MERRAPFIX}${vv}_SEP_$((${YEAR}-1))_AUG_${YEAR}_anom${ENDFIX}

  done # while [ ${YEAR} -lt $((${FIYEAR}+1)) ]; do

  rm `ls -1 ${WORKDIR}/${vv}_*`
  rm `ls -1 ${WORKDIR}/anom_${vv}_*`

done # for vv in ${MERRAVAR[@]}; do

