#!/bin/bash
#PBS -P w97
#PBS -q express
#PBS -l walltime=2:00:00,mem=12GB
#PBS -l wd

module purge
module load pbs dot
module load netcdf/4.4.1.1
module load nco
module load cdo/1.8.2

# This script splits up the EHF 30 year daily data files to limit it just to the summer months

#Author: Annette Hirsch @ CCRC, UNSW. Sydney (Australia)
#email: a.hirsch@unsw.edu.au
#Created: Thu Apr 19 09:02:25 AEST 2018 

## Input arguments

WORKDIR='/short/w97/azh561/tmp/'
MODOUTDIR1="/g/data3/w97/azh561/cordex_australasia/post_process/Raw/ECMWF-ERAINT/"

# UNSW WRF simulations
#MODINDIR1="/g/data3/hh5/tmp/w28/gdv561/CORDEX/ERA-Int/ERA-Interim_post/postprocess/CORDEX/output/AUS-44i/UNSW/ECMWF-ERAINT/evaluation/r1i1p1/"
#MODINDIR2="/v1/d01/day/"
#MODELS=( "UNSW-WRF360J" "UNSW-WRF360K" "UNSW-WRF360L" )
#MODELS=( "UNSW-WRF360J" "UNSW-WRF360K" )
#MODVAR=( "albedo" "hfls" "hfss" "mrso" "rlds" "rsds" "rsus" "rlus" "tas" "tasmin" "tasmax" "pr")
#MODELS=( "UNSW-WRF360L" )
#MODVAR=( "albedo" "hfls" "hfss" "mrso" "rsds" "rsus" "rlus" "tas" "tasmin" "tasmax" "pr")
#MODVAR=( "rlds" )

# COSMO-CLM simulations
#MODINDIR1="/g/data3/w97/azh561/cordex_australasia/CCLM4-8/AUS-44i/"
#MODINDIR2="/day/"
#MODELS=( "CLMcom-CCLM4-8-17-CLM3-5" )
#MODVAR=( "hfls" "hfss" "mrso" "rlds" "rsds" "rsus" "rlus" "tas" "tasmin" "tasmax" "pr" "ts" )

# CCAM simulations
MODINDIR1="/g/data3/w97/azh561/cordex_australasia/"
MODELS=( "CSIRO-CCAM" )
MODINDIR2="/day/"
#MODVAR=( "hfls" "hfss" "mrso" "rlds" "rsds" "rsus" "tas" "tasmin" "tasmax" "pr" "ts" )
MODVAR=( "rlus" )

# Murdoch WRF simulations
#MODINDIR1="/g/data3/w97/azh561/cordex_australasia/MU-WRF/AUS-44i/"
#MODELS=( "MU-WRF330" )
#MODINDIR2="/day/"
#MODVAR=( "albedo" "hfls" "hfss" "mrso" "rlds" "rsds" "rsus" "tas" "tasmin" "tasmax" "pr" "ts" )


MODOUTDIR2="/1981-2009/AUS-44i/"
MODPFIX="CORDEX-AustralAsia_1981-2009_"

ENDFIX=".nc"


SYEAR=1981
EYEAR=2009

# Model data
for mm in ${MODELS[@]}; do

  for vv in ${MODVAR[@]}; do

    INFILES=`ls -1 ${MODINDIR1}${mm}${MODINDIR2}${vv}/${vv}*.nc`
    #INFILES=`ls -1 ${MODINDIR1}${mm}${MODINDIR2}${vv}/${vv}*r1p1i1*.nc` # For UNSW-WRF360L rlds
    for i in ${INFILES[@]}; do
      cdo splityearmon ${i} "${WORKDIR}/${vv}_"
      cdo splityear ${i} "${WORKDIR}/${vv}_"
    done

  ncrcat `ls -1 ${WORKDIR}/${vv}_198[1-9].nc` `ls -1 ${WORKDIR}/${vv}_199[0-9].nc` `ls -1 ${WORKDIR}/${vv}_200[0-9].nc` ${WORKDIR}/${vv}_${SYEAR}_${EYEAR}.nc
  cdo ydaymean ${WORKDIR}/${vv}_${SYEAR}_${EYEAR}.nc ${WORKDIR}/${vv}_${SYEAR}_${EYEAR}_ydaymean.nc

  YEAR=${SYEAR}
  while [ ${YEAR} -lt $((${EYEAR}+1)) ]; do

    # Calculate the anomalies
    cdo ydaysub ${WORKDIR}/${vv}_${YEAR}.nc ${WORKDIR}/${vv}_${SYEAR}_${EYEAR}_ydaymean.nc ${WORKDIR}/anom_${vv}_${YEAR}.nc
    cdo splitmon ${WORKDIR}/anom_${vv}_${YEAR}.nc ${WORKDIR}/anom_${vv}_${YEAR}
    YEAR=$((${YEAR}+1))

  done # while [ ${YEAR} -lt $((${FIYEAR}+1)) ]; do


    YEAR=${SYEAR}
    while [ ${YEAR} -lt ${EYEAR} ]; do

      ncrcat `ls -1 ${WORKDIR}/${vv}_${YEAR}1[0-2].nc` ${WORKDIR}/${vv}_${YEAR}_OND.nc
      ncrcat `ls -1 ${WORKDIR}/anom_${vv}_${YEAR}1[0-2].nc` ${WORKDIR}/anom_${vv}_${YEAR}_OND.nc
      ncrcat `ls -1 ${WORKDIR}/${vv}_${YEAR}09.nc` `ls -1 ${WORKDIR}/${vv}_${YEAR}1[0-2].nc` ${WORKDIR}/${vv}_${YEAR}_SOND.nc
      ncrcat `ls -1 ${WORKDIR}/anom_${vv}_${YEAR}09.nc` `ls -1 ${WORKDIR}/anom_${vv}_${YEAR}1[0-2].nc` ${WORKDIR}/anom_${vv}_${YEAR}_SOND.nc
      YEAR=$((${YEAR}+1))
      ncrcat `ls -1 ${WORKDIR}/${vv}_${YEAR}0[1-3].nc` ${WORKDIR}/${vv}_${YEAR}_JFM.nc
      ncrcat `ls -1 ${WORKDIR}/anom_${vv}_${YEAR}0[1-3].nc` ${WORKDIR}/anom_${vv}_${YEAR}_JFM.nc
      ncrcat `ls -1 ${WORKDIR}/${vv}_${YEAR}0[1-8].nc` ${WORKDIR}/${vv}_${YEAR}_JFMAMJJA.nc
      ncrcat `ls -1 ${WORKDIR}/anom_${vv}_${YEAR}0[1-8].nc` ${WORKDIR}/anom_${vv}_${YEAR}_JFMAMJJA.nc
      ncrcat ${WORKDIR}/${vv}_$((${YEAR}-1))_OND.nc ${WORKDIR}/${vv}_${YEAR}_JFM.nc ${WORKDIR}/${vv}_${YEAR}_ONDJFM.nc
      ncrcat ${WORKDIR}/anom_${vv}_$((${YEAR}-1))_OND.nc ${WORKDIR}/anom_${vv}_${YEAR}_JFM.nc ${WORKDIR}/anom_${vv}_${YEAR}_ONDJFM.nc
      ncrcat ${WORKDIR}/${vv}_$((${YEAR}-1))_SOND.nc ${WORKDIR}/${vv}_${YEAR}_JFMAMJJA.nc ${WORKDIR}/${vv}_SEP_$((${YEAR}-1))_AUG_${YEAR}.nc
      ncrcat ${WORKDIR}/anom_${vv}_$((${YEAR}-1))_SOND.nc ${WORKDIR}/anom_${vv}_${YEAR}_JFMAMJJA.nc ${WORKDIR}/anom_${vv}_SEP_$((${YEAR}-1))_AUG_${YEAR}.nc
      mv ${WORKDIR}/${vv}_${YEAR}_ONDJFM.nc ${MODOUTDIR1}${mm}${MODOUTDIR2}${MODPFIX}${vv}_${YEAR}_ONDJFM${ENDFIX}
      mv ${WORKDIR}/anom_${vv}_${YEAR}_ONDJFM.nc ${MODOUTDIR1}${mm}${MODOUTDIR2}${MODPFIX}${vv}_${YEAR}_ONDJFM_anom${ENDFIX}
      mv ${WORKDIR}/${vv}_SEP_$((${YEAR}-1))_AUG_${YEAR}.nc ${MODOUTDIR1}${mm}${MODOUTDIR2}${MODPFIX}${vv}_SEP_$((${YEAR}-1))_AUG_${YEAR}${ENDFIX}
      mv ${WORKDIR}/anom_${vv}_SEP_$((${YEAR}-1))_AUG_${YEAR}.nc ${MODOUTDIR1}${mm}${MODOUTDIR2}${MODPFIX}${vv}_SEP_$((${YEAR}-1))_AUG_${YEAR}_anom${ENDFIX}

    done # while [ ${YEAR} -lt $((${FIYEAR}+1)) ]; do
    rm `ls -1 ${WORKDIR}/${vv}_*`
    rm `ls -1 ${WORKDIR}/anom_${vv}_*`

  done # for vv in ${MODVAR[@]}; do

done # for mm in ${MODELS[@]}; do


