#!/bin/bash
#PBS -P w97
#PBS -q express
#PBS -l walltime=2:00:00,mem=12GB
#PBS -l wd

module purge
module load pbs dot
module load netcdf/4.4.1.1
module load nco
module load cdo/1.8.2

# This script splits up the EHF 30 year daily data files to limit it just to the summer months

#Author: Annette Hirsch @ CCRC, UNSW. Sydney (Australia)
#email: a.hirsch@unsw.edu.au
#Created: Thu Apr 19 09:02:25 AEST 2018 

## Input arguments

WORKDIR='/short/w97/azh561/tmp/'

MODDIR="/g/data3/w97/azh561/cordex_australasia/post_process/Raw/ECMWF-ERAINT/"
MODELS=( "UNSW-WRF360J" "UNSW-WRF360K" "UNSW-WRF360L" "CLMcom-CCLM4-8-17-CLM3-5" "CSIRO-CCAM" "MU-WRF330" )
MODDIR2="/1981-2009/AUS-44i/"
MODPFIX="CORDEX-AustralAsia_1981-2009_"
MODVAR=( "EHF" "spell" )
ENDFIX="_PA13.nc"

for mm in ${MODELS[@]}; do

  for vv in ${MODVAR[@]}; do

    cdo splityearmon ${MODDIR}${mm}${MODDIR2}${MODPFIX}${vv}${ENDFIX} "${WORKDIR}/${mm}_${vv}_"
    SFILE=`ls -1 ${WORKDIR}/${mm}_${vv}_*.nc | head -1`
    EFILE=`ls -1 ${WORKDIR}/${mm}_${vv}_*.nc | tail -1`
    SYEAR=${SFILE: -9:4}
    EYEAR=${EFILE: -9:4}
    YEAR=${SYEAR}

    while [ ${YEAR} -lt ${EYEAR} ]; do

      ncrcat `ls -1 ${WORKDIR}/${mm}_${vv}_${YEAR}1[0-2].nc` ${WORKDIR}/${mm}_${vv}_${YEAR}_OND.nc
      ncrcat `ls -1 ${WORKDIR}/${mm}_${vv}_${YEAR}09.nc` `ls -1 ${WORKDIR}/${mm}_${vv}_${YEAR}1[0-2].nc` ${WORKDIR}/${mm}_${vv}_${YEAR}_SOND.nc
      YEAR=$((${YEAR}+1))
      ncrcat `ls -1 ${WORKDIR}/${mm}_${vv}_${YEAR}0[1-3].nc` ${WORKDIR}/${mm}_${vv}_${YEAR}_JFM.nc
      ncrcat `ls -1 ${WORKDIR}/${mm}_${vv}_${YEAR}0[1-8].nc` ${WORKDIR}/${mm}_${vv}_${YEAR}_JFMAMJJA.nc
      ncrcat ${WORKDIR}/${mm}_${vv}_$((${YEAR}-1))_OND.nc ${WORKDIR}/${mm}_${vv}_${YEAR}_JFM.nc ${WORKDIR}/${mm}_${vv}_${YEAR}_ONDJFM.nc
      ncrcat ${WORKDIR}/${mm}_${vv}_$((${YEAR}-1))_SOND.nc ${WORKDIR}/${mm}_${vv}_${YEAR}_JFMAMJJA.nc ${WORKDIR}/${mm}_${vv}_SEP_$((${YEAR}-1))_AUG_${YEAR}.nc
      mv ${WORKDIR}/${mm}_${vv}_${YEAR}_ONDJFM.nc ${MODDIR}${mm}${MODDIR2}${MODPFIX}${vv}_${YEAR}_ONDJFM${ENDFIX}
      mv ${WORKDIR}/${mm}_${vv}_SEP_$((${YEAR}-1))_AUG_${YEAR}.nc ${MODDIR}${mm}${MODDIR2}${MODPFIX}${vv}_SEP_$((${YEAR}-1))_AUG_${YEAR}${ENDFIX}

    done # while [ ${YEAR} -lt $((${FIYEAR}+1)) ]; do
    rm `ls -1 ${WORKDIR}/${mm}_${vv}_*`

  done # for vv in ${MODVAR[@]}; do

done # for mm in ${MODELS[@]}; do


